##  Video Tutorial
The following video tutorial provides an overview of application modeling guidelines and best practices.
![Video thumbnail](https://cdnapisec.kaltura.com/html5/html5lib/v2.101/modules/KalturaSupport/thumbnail.php/p/1921661/uiconf_id/37285991/entry_id/1_2isyqppx/height/480?&flashvars\[parentDomain\]=https%3A%2F%2Fhelp.sap.com%2Fdocs%2Fleanix%2Fea%2Fapplication-modeling-guidelines%3Fversion%3DCLOUD)
